@@ -254,7 +254,6 @@ bjb_controller_add_item (BjbController *self,
   GdkPixbuf     *pix = NULL;
   const gchar   *uuid;
   BjbWindowBase  *win;
-  BjbWindowViewType type;
 
   g_return_if_fail (BIJI_IS_ITEM (item));
   store = GTK_LIST_STORE (self->priv->model);
@@ -278,10 +277,7 @@ bjb_controller_add_item (BjbController *self,
   /* First , if there is a gd main view , and if gd main view
    * is a list, then load the smaller emblem */
   win = self->priv->window;
-  type = bjb_window_base_get_view_type (win);
-  if ((type == BJB_WINDOW_BASE_MAIN_VIEW ||
-       type == BJB_WINDOW_BASE_ARCHIVE_VIEW)
-      && bjb_window_base_get_main_view (win)
+  if (bjb_window_base_get_main_view (win)
       && bjb_main_view_get_view_type
                 (bjb_window_base_get_main_view (win)) == GD_MAIN_VIEW_LIST)
     pix = biji_item_get_emblem (item);
@@ -451,6 +447,40 @@ update (BjbController *self)
 }
 
 
+
+static void
+_add_if_group_match (BjbController  *self,
+                    GList         **to_show,
+                    gpointer       *item,
+                    gint           *count)
+{
+  gboolean trashed, match;
+  BijiNoteObj *note;
+
+  if (BIJI_IS_NOTE_OBJ (*item))
+  {
+    match = FALSE;
+    note = BIJI_NOTE_OBJ (*item);
+    trashed = biji_note_obj_is_trashed (note);
+
+    if ((trashed==FALSE && self->priv->group == BIJI_LIVING_ITEMS) ||
+        (trashed==TRUE  && self->priv->group == BIJI_ARCHIVED_ITEMS))
+      match = TRUE;
+  }
+
+  else
+  {
+    match = TRUE;
+  }
+
+  if (match)
+  {
+    *to_show = g_list_prepend (*to_show, *item);
+    *count = *count + 1;
+  }
+}
+
+
 static void
 update_controller_callback (GList *result,
                             gpointer user_data)
@@ -466,23 +496,12 @@ update_controller_callback (GList *result,
 
 
 
-  if (!result)
+  if (!result && priv->group == BIJI_LIVING_ITEMS)
   {
     bjb_window_base_switch_to (priv->window, BJB_WINDOW_BASE_NO_RESULT);
     return;
   }
 
-  switch (self->priv->group)
-  {
-    case BIJI_ARCHIVED_ITEMS:
-      bjb_window_base_switch_to (priv->window, BJB_WINDOW_BASE_ARCHIVE_VIEW);
-      break;
-
-    default:
-      break;
-  }
-
-
   sort_items (&result);
   i = 0;
 
@@ -493,8 +512,10 @@ update_controller_callback (GList *result,
   {
     if (i< priv->n_items_to_show)
     {
-      priv->items_to_show = g_list_prepend (priv->items_to_show, l->data);
-      i ++;
+      _add_if_group_match (self,
+                           &priv->items_to_show,
+                           &l->data,
+			   &i);
     }
 
     else if (l->next != NULL)
@@ -506,12 +527,21 @@ update_controller_callback (GList *result,
 
   priv->items_to_show = g_list_reverse (priv->items_to_show);
   update (self);
+
+  switch (self->priv->group)
+  {
+    case BIJI_ARCHIVED_ITEMS:
+      bjb_window_base_switch_to (priv->window, BJB_WINDOW_BASE_ARCHIVE_VIEW);
+      break;
+
+    default:
+      break;
+  }
+
 }
 
 
 
-
-
 void
 bjb_controller_apply_needle (BjbController *self)
 {
@@ -522,12 +552,13 @@ bjb_controller_apply_needle (BjbController *self)
   needle = priv->needle;
   g_clear_pointer (&priv->items_to_show, g_list_free);
 
-  /* Show all notes */
+  /* Show all items
+   * If no items, tell it - unless trash is visited */
   if (needle == NULL || g_strcmp0 (needle,"") == 0)
   {
     result = biji_manager_get_items (self->priv->manager, self->priv->group);
 
-    if (result == NULL)
+    if (result == NULL && priv->group == BIJI_LIVING_ITEMS)
       bjb_window_base_switch_to (self->priv->window, BJB_WINDOW_BASE_NO_NOTE);
 
     else
@@ -593,6 +624,7 @@ on_manager_changed (BijiManager            *manager,
 
     /* Same comment, prepend but notebook before note */
     case BIJI_MANAGER_NOTE_AMENDED:
+    case BIJI_MANAGER_ITEM_ICON_CHANGED:
       if (bjb_controller_get_iter (self, item, &p_iter))
       {
         gtk_list_store_remove (GTK_LIST_STORE (priv->model), p_iter);
@@ -607,20 +639,6 @@ on_manager_changed (BijiManager            *manager,
       }
       break;
 
-    /* If color changed we just amend the icon */
-    case BIJI_MANAGER_ITEM_ICON_CHANGED:
-      if (bjb_main_view_get_view_type (
-             bjb_window_base_get_main_view (self->priv->window)) == GD_MAIN_VIEW_ICON
-          && bjb_controller_get_iter (self, item, &p_iter))
-        gtk_list_store_set (GTK_LIST_STORE (priv->model), p_iter,
-                            GD_MAIN_COLUMN_ICON, biji_item_get_icon (item), -1);
-      else if (bjb_main_view_get_view_type (
-             bjb_window_base_get_main_view (self->priv->window)) == GD_MAIN_VIEW_LIST
-          && bjb_controller_get_iter (self, item, &p_iter))
-        gtk_list_store_set (GTK_LIST_STORE (priv->model), p_iter,
-                            GD_MAIN_COLUMN_ICON, biji_item_get_emblem (item), -1);
-      break;
-
     case BIJI_MANAGER_ITEM_DELETED:
     case BIJI_MANAGER_ITEM_TRASHED:
     case BIJI_MANAGER_ITEM_RESTORED:
