@@ -198,7 +198,7 @@ static gboolean
 on_view_mode_clicked (GtkWidget *button, BjbMainToolbar *self)
 {
   GdMainViewType current = bjb_main_view_get_view_type (self->priv->parent);
-    
+
   switch ( current )
   {
     case GD_MAIN_VIEW_ICON :
@@ -282,6 +282,9 @@ update_selection_buttons (BjbController *controller,
   if (priv->list)
     gtk_widget_set_sensitive (priv->list, some_item_is_visible);
 
+  if (priv->empty_bin)
+    gtk_widget_set_sensitive (priv->empty_bin, some_item_is_visible);
+
   gtk_widget_set_sensitive (priv->select, some_item_is_visible);
 }
 
@@ -564,7 +567,9 @@ populate_bar_for_trash (BjbMainToolbar *self)
   if (priv->type == BJB_TOOLBAR_TRASH_LIST)
     add_grid_button (self);
 
-  /* Add Empty-Bin */
+  /* Add Empty-Bin
+   * translators : Empty is the verb.
+   * This action permanently deletes notes */
   priv->empty_bin = gtk_button_new_with_label(_("Empty"));
   context = gtk_widget_get_style_context (priv->empty_bin);
   gtk_style_context_add_class (context, "destructive-action");
@@ -588,6 +593,9 @@ populate_bar_for_trash (BjbMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self), TRUE);
 
   /* Watch for main view changing */
+  update_selection_buttons (
+    priv->controller, bjb_controller_shows_item (priv->controller),
+    FALSE,priv);
   connect_main_view_handlers (self);
 }
 
