@@ -291,6 +291,23 @@ biji_manager_notify_changed (BijiManager            *manager,
 static void
 on_item_deleted_cb (BijiItem *item, BijiManager *manager)
 {
+  BijiItem        *to_delete;
+  const gchar     *path;
+  gboolean         retval;
+
+
+  to_delete = NULL;
+  retval = FALSE;
+  path = biji_item_get_uuid (item);
+  to_delete = g_hash_table_lookup (manager->priv->archives, path);
+
+  if (to_delete != NULL)
+    retval = TRUE;
+
+  if (!retval)
+    return;
+
+  g_hash_table_remove (manager->priv->archives, path);
   biji_manager_notify_changed (manager,
                                BIJI_ARCHIVED_ITEMS,
                                BIJI_MANAGER_ITEM_DELETED,
@@ -302,6 +319,9 @@ on_item_deleted_cb (BijiItem *item, BijiManager *manager)
  * old uuid : we need this because local provider uses
  * file name as uuid. Now this proves this is not right.
  *
+ * save : in order to restore the note inside tracker
+ *
+ *
  * notify... BIJI_ARCHIVED_ITEM
  * well, works currently : we assume Archives change.
  * but we might double-ping as well
@@ -310,6 +330,9 @@ on_item_deleted_cb (BijiItem *item, BijiManager *manager)
 static void
 on_item_restored_cb (BijiItem *item, gchar *old_uuid, BijiManager *manager)
 {
+  if (BIJI_IS_NOTE_OBJ (item))
+    biji_note_obj_save_note (BIJI_NOTE_OBJ (item));
+
   g_hash_table_insert (manager->priv->items,
                        (gpointer) biji_item_get_uuid (item), item);
   g_hash_table_remove (manager->priv->archives, old_uuid);
@@ -668,21 +691,23 @@ biji_manager_load_archives          (BijiManager        *manager)
 
 
 static void
-_delete_item (gpointer key,
-              gpointer value,
+_delete_item (gpointer data,
               gpointer user_data)
 {
-  BijiItem *i;
-
-  i = BIJI_ITEM (value);
-  biji_item_delete (i);
+  biji_item_delete (BIJI_ITEM (data));
 }
 
 
+/* Do not g_list_free_full here.
+ * We only unref items where deletion works */
 void
-biji_manager_empty_bin              (BijiManager        *manager)
+biji_manager_empty_bin              (BijiManager        *self)
 {
-  g_hash_table_foreach (manager->priv->archives, _delete_item, NULL);
+  GList *items;
+
+  items = g_hash_table_get_values (self->priv->archives);
+  g_list_foreach (items, _delete_item, NULL);
+  g_list_free (items);
 }
 
 
